@@ -29,20 +29,20 @@ _pkg_config = {
     'android_abi':        '',
     'arch':               '',
     'default_bin_dir':    '/usr/bin',
-    'default_mod_dir':    '/usr/lib/python3.11/site-packages',
+    'default_mod_dir':    '/usr/lib/python3.10/site-packages',
     'default_sip_dir':    '/usr/share/sip',
     'deployment_target':  '',
     'platform':           'linux-g++',
-    'py_conf_inc_dir':    '/usr/include/python3.11',
-    'py_inc_dir':         '/usr/include/python3.11',
-    'py_lib_dir':         '/usr/lib/python3.11/config',
-    'py_version':         0x030b05,
+    'py_conf_inc_dir':    '/usr/include/python3.10',
+    'py_inc_dir':         '/usr/include/python3.10',
+    'py_lib_dir':         '/usr/lib/python3.10/config',
+    'py_version':         0x030a08,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/sip4/src=/usr/src/debug/sip4 -flto=auto LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto --no-dist-info',
-    'sip_inc_dir':        '/usr/include/python3.11',
-    'sip_module_dir':     '/usr/lib/python3.11/site-packages',
-    'sip_root_dir':       '/usr/lib/python3.11/site-packages',
+    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/sip4/src=/usr/src/debug/sip4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'sip_inc_dir':        '/usr/include/python3.10',
+    'sip_module_dir':     '/usr/lib/python3.10/site-packages',
+    'sip_root_dir':       '/usr/lib/python3.10/site-packages',
     'sip_version':        0x041319,
     'sip_version_str':    '4.19.25',
     'universal':          ''
@@ -52,7 +52,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/sip4/src=/usr/src/debug/sip4 -flto=auto',
+    'CFLAGS':                   '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/sip4/src=/usr/src/debug/sip4',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
@@ -101,7 +101,7 @@ _default_macros = {
     'INCDIR':                   '',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto',
+    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
